import React from 'react'
import { Menu } from '@pubsweet/ui'
import { startsWith, toLower, get } from 'lodash'
import { compose, withState, withHandlers } from 'recompose'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'

import { withCountries } from 'pubsweet-component-faraday-ui'

const filteredCountries = (countries, userInput) =>
  countries.filter(o => startsWith(toLower(o.label), toLower(userInput)))

const firstFilteredCountry = props =>
  filteredCountries(props.countries, props.userInput)[0]

const CustomOpener = ({
  selected,
  userInput,
  toggleMenu,
  placeholder,
  optionLabel,
  onChange,
  onEnter,
}) => (
  <Input
    onChange={onChange}
    onClick={toggleMenu}
    onKeyUp={onEnter}
    placeholder={selected ? optionLabel(selected) : placeholder}
    value={userInput}
  />
)

const MenuCountry = ({ countries = [], ...input }) => (
  <Menu
    {...input}
    options={filteredCountries(countries, input.userInput)}
    placeholder="Please select"
    renderOpener={CustomOpener}
  />
)

const enhance = compose(
  withCountries,
  withState('userInput', 'updateUserInput', ''),
  withHandlers({
    onChange: ({ updateUserInput, onChange }) => value => {
      // this value is an input DOM event while typing and a dropdown value when
      // selected
      if (typeof value === 'string') {
        onChange(value)
      }
      updateUserInput(get(value, 'target.value', ''))
    },
    onEnter: props => event => {
      if (event.which === 13) {
        props.onChange(firstFilteredCountry(props).value)
        props.updateUserInput(firstFilteredCountry(props).label)
      }
    },
  }),
)

export default enhance(MenuCountry)

const Input = styled.input`
  width: 100%;
  height: calc(${th('gridUnit')} * 4);
  border: ${th('accordion.border')};
  border-radius: ${th('borderRadius')};
  padding: 0 ${th('gridUnit')};
  ::placeholder {
    color: ${th('colorText')};
    opacity: 1;
    font-family: ${th('fontWriting')};
  }
  :focus {
    border-color: ${th('action.colorActive')}
    outline: none;
  }
`
